# cytominer_database

[![Build Status](https://travis-ci.org/cytomining/cytominer-database.svg?branch=master)](https://travis-ci.org/cytomining/cytominer-database)
[![Documentation Status](https://readthedocs.org/projects/cytominer-database/badge/?version=stable)](http://cytominer-database.readthedocs.io/en/stable/?badge=stable)
[![Dependency Status](https://gemnasium.com/badges/github.com/cytomining/cytominer-database.svg)](https://gemnasium.com/github.com/cytomining/cytominer-database)

A package for storing morphological profiling data.
